@@ -30,7 +30,13 @@ inline
 double
 W_mer_log_likelihood( const likelihoods_vec_t & log_likelihoods, size_t offset, size_t W ) {
     if( log_likelihoods.size() <= offset + W - 1 ) {
-        throw std::invalid_argument( "Offset out of range. " );
+        throw std::invalid_argument(
+            MS_MAKE_STRING(
+                "Offset out of range: "
+                << log_likelihoods.size() << " <= "
+                << offset << " + " << W << " - 1"
+            )
+        );
     }
     return log_likelihoods[ offset + W - 1 ] - ( offset ? log_likelihoods[ offset - 1 ] : 0. );
 }
