@@ -12,6 +12,7 @@
 #include <myrrh/seqan_boost_range_adaptors.h>
 
 #include <seqan.h>
+#include <seqan/version.h>
 
 #include <boost/foreach.hpp>
 #include <boost/iterator/transform_iterator.hpp>
@@ -29,6 +30,14 @@
 #include <string>
 
 
+#if SEQAN_VERSION_MAJOR > 1 || SEQAN_VERSION_MINOR > 3
+# define SEQAN_PACK Pack
+# define SEQAN_BITPACKED BitPacked
+#else
+# define SEQAN_PACK Compressed
+# define SEQAN_BITPACKED BitCompressed
+#endif
+
 /// log(.5)
 #define STEME_LOG_HALF -0.69314718055994529
 
