@@ -409,7 +409,7 @@ struct tree_descender
 			const typename seqan::Value< occurrences_t >::Type & occ = occs[ i ];
 
 			// get the global position to know where to store the Z
-			const int global_pos = seqan::posGlobalize( occ, _data.get_string_set_limits() );
+			const global_pos_t global_pos = seqan::posGlobalize( occ, _data.get_string_set_limits() );
 
 			// prior
 			const double g_n = _model._prior._psp->get_g( occ.i1, occ.i2 );
